@@ -640,13 +640,14 @@ def _start(client, bot):
 					topos=0
 					for t, u in top:
 						try:
-							if line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="server":
-								t = discord.utils.get(client.guilds, id=int(t))
-							else:
-								t = discord.utils.get(client.get_all_members(), id=int(t))
-							if t:
-								topos+=1
-								topstr+=str(topos)+". "+str(t)+" - "+str(u)+"\n"
+							if topos<=int(line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2]):
+								if line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="server":
+									t = discord.utils.get(client.guilds, id=int(t))
+								else:
+									t = discord.utils.get(client.get_all_members(), id=int(t))
+								if t:
+									topos+=1
+									topstr+=str(topos)+". "+str(t)+" - "+str(u)+"\n"
 						except:
 							pass
 					while len(topstr)>2000:
